<?php
// Author: Kevin K.M. Chiu
// Copyright 2000, Cobalt Networks.  All rights reserved.
// $Id: loginHandler.php,v 1.24.4.1 2001/12/14 04:14:11 pmartin Exp $

// description:
// This handler handles login tasks to the system through CCE authentication
// and set cookies to the browser appropriately.
//
// usage:
// The configurable variables are:
// newLoginName - the login name to CCE
// newLoginPassword - the login password to CCE
// timeStamp - the time in number of seconds since Epoch on the browser machine
// target - the URL to go to if login succeed. For security reasons, it must
//     start with a slash "/"
// fallback - the URL to fallback to if login fails. Optional. If not supplied,
//     goes back to where the handler is called from by default
// reuseWindow - if true, no new window is launched. Optional.
// windowWidth - the width of the new window.  Optional.
// windowHeight - the height of the new window.  Optional.

include("CceClient.php");
include("I18n.php");

// connect to CCE
$cceClient = new CceClient();
if(!$cceClient->connect()) {
  $locale = $HTTP_ACCEPT_LANGUAGE;
  if($HTTP_ACCEPT_LANGUAGE == "") {
    include ("System.php");
    $system = new System();
    $locale = $system->getConfig("defaultLocale");
  }
  $i18n = new I18n("palette", $locale);

  $cceDown = $i18n->get("cceDown");

  print("
<HTML>
  <HEAD>
    <META HTTP-EQUIV=\"expires\" CONTENT=\"-1\">
    <META HTTP-EQUIV=\"Pragma\" CONTENT=\"no-cache\">
  </HEAD>
  <BODY>
    <CENTER>
    <BR><BR><BR><BR>
    <FONT COLOR=\"#990000\">$cceDown</FONT>
    </CENTER>
  </BODY>
  <HEAD>
    <META HTTP-EQUIV=\"Pragma\" CONTENT=\"no-cache\">
  </HEAD>
</HTML>
");

  error_log("loginHandler.php: $cceDown");
  exit;
}

// check to see if the user is already logged in as another
// user:
// $HTTP_COOKIE_VARS["loginName"] $HTTP_COOKIE_VARS["sessionId"]
if ($HTTP_COOKIE_VARS["loginName"] && $HTTP_COOKIE_VARS["sessionId"])
{
  // release the old session id
  $cceClient->authkey($HTTP_COOKIE_VARS["loginName"],
    $HTTP_COOKIE_VARS["sessionId"]);
  $cceClient->endkey(); # release the session id
  $cceClient = new CceClient();
  $cceClient->connect();
}

// get session ID
$sessionId = $cceClient->auth($newLoginName, $newLoginPassword);

// phpinfo();

// bye
// $cceClient->bye();

// auth failed?
if($sessionId == "") {
  // figure out the next step
  $secure = "";
  if ($HTTP_POST_VARS["secure"]) {
	$secure="&secure=1";
  }
  $nextStep = ($fallback != "") ? "location.replace('$fallback')" : "location.replace('/login.php?authFailed=true$secure' )";

  header("cache-control: no-cache");
  print("
<HTML>
  <HEAD>
    <META HTTP-EQUIV=\"expires\" CONTENT=\"-1\">
    <META HTTP-EQUIV=\"Pragma\" CONTENT=\"no-cache\">
  </HEAD>
  <BODY onLoad=\"$nextStep\"></BODY>
  <HEAD>
    <META HTTP-EQUIV=\"Pragma\" CONTENT=\"no-cache\">
  </HEAD>
</HTML>
");

  exit;
}

// expire in 2 hours
$expirationTime = $timeStamp+7200;

// send cookie
setcookie("loginName", $newLoginName, "$expirationTime");
setcookie("sessionId", $sessionId, "$expirationTime");

// only use URLs of this machine
if(substr($target, 0, 1) != "/")
  exit();

header("cache-control: no-cache");

if($reuseWindow)
  print "
<HTML>
  <HEAD>
    <META HTTP-EQUIV=\"expires\" CONTENT=\"-1\">
    <META HTTP-EQUIV=\"Pragma\" CONTENT=\"no-cache\">
  </HEAD>
  <BODY onLoad=\"location.replace('$target')\"></BODY>
  <HEAD>
    <META HTTP-EQUIV=\"Pragma\" CONTENT=\"no-cache\">
  </HEAD>
</HTML>
";
else{
  if($windowWidth && $windowHeight){
    $widthAndHeight="width=$windowWidth,height=$windowHeight,";
  }else{
    $widthAndHeight="";
  }

  print "
<HTML>
<HEAD>
<META HTTP-EQUIV=\"expires\" CONTENT=\"-1\">
<META HTTP-EQUIV=\"Pragma\" CONTENT=\"no-cache\">
<SCRIPT LANGUAGE=\"javascript\">
function init() {
  if(navigator.appName.indexOf(\"Microsoft\") != -1)
    // IE need to use a unique window name here because it throws access denied
    // error when window name is reused
    // we cannot call focus() here because IE gives paranoid access denied
    window.open(\"$target\", (new Date()).getTime(), \"".$widthAndHeight."menubar=yes,resizable=yes\");
  else {
    var windowReference = window.open(\"$target\", \"launchedWindow\", \"".$widthAndHeight."menubar=yes,resizable=yes\");
    windowReference.focus();
  }


  location.replace(\"/loggedIn.php\");
}

</SCRIPT>
</HEAD>
<BODY onLoad=\"init()\"></BODY>
<HEAD>
<META HTTP-EQUIV=\"Pragma\" CONTENT=\"no-cache\">
</HEAD>
</HTML>
";
}
?>
